@@ -19,6 +19,7 @@
 
 #include <stdlib.h>
 #include <iostream.h>
+#include <string.h>
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -37,16 +38,23 @@
 #include "copyright.h"
 #include "reportbugs.h"
 
+// for globals
+#include "linenumdigit.h"
+#include "globalostream.h"
+#include "cmdlineargs.h"
+
 // global output stream
 ostream* sout;
 
 int tabSpaces = 0;     // space to substitue to tabs
 char *tags_file = 0; // possible tags file
+unsigned int line_num_digit = 0; // num of digits to represent line number
 
-StartApp::StartApp(char *prog_name, char *prog_ver) :
+gengetopt_args_info args_info ;     // command line structure
+
+StartApp::StartApp() :
   entire_doc (0), verbose (0), cssUrl (0),
-  use_css (0), is_cgi (0), programName (prog_name),
-  programVersion (prog_ver)
+  use_css (0), is_cgi (0)
 {
 }
 
@@ -61,7 +69,6 @@ StartApp::start(int argc, char * argv[])
   char *header_fileName = 0;
   char *footer_fileName = 0;
   char **temp_argv;
-  gengetopt_args_info args_info ;     // command line structure
   unsigned i;
   int v; 
 
@@ -76,19 +83,26 @@ StartApp::start(int argc, char * argv[])
 
   if (args_info.version_given)
     {
-      print_version (programName, programVersion);
+      print_version ();
       print_copyright ();
       exit (0);
     }
 
   if (args_info.help_given)
     {
-      print_version (programName, programVersion);
+      cout << "GNU ";
       cmdline_parser_print_help ();
       print_reportbugs ();
       exit (0);
     }
 
+  if (strcmp (args_info.out_format_arg, "html") != 0)
+    {
+      cerr << PACKAGE << ": output format " << args_info.out_format_arg
+           << " not recognized" << endl;
+      exit (1);
+    }
+
   /* initialization of global symbols */
   inputFileName = outputFileName = 0 ;
   sout = 0 ;
@@ -106,15 +120,16 @@ StartApp::start(int argc, char * argv[])
     tabSpaces = args_info.tab_arg ;
 
   if (header_fileName)
-    docHeader = read_file (programName, header_fileName);
+    docHeader = read_file (header_fileName);
 
   if (footer_fileName)
-    docFooter = read_file (programName, footer_fileName);
+    docFooter = read_file (footer_fileName);
 
   cssUrl = args_info.css_arg ;
   use_css = ( cssUrl != 0 ) ;
 
-  entire_doc = ( args_info.doc_given || (docTitle != 0) || use_css ) ;
+  entire_doc = ( args_info.doc_given || (docTitle != 0) || use_css ||
+                 docHeader || docFooter ) ;
   
   inputFileName = args_info.input_arg ;
   if ( inputFileName && ! is_cgi ) {
@@ -128,18 +143,18 @@ StartApp::start(int argc, char * argv[])
   if ( verbose )
     setMessager( new DefaultMessages ) ;
 
-  printMessage( programName ) ; // FIXME
-  printMessage( programVersion ) ;
+  printMessage( PACKAGE ) ;
+  printMessage( VERSION ) ;
   
   parseTags() ;
 
   CharTranslator *translator = createCharTranslator ();
 
   if( use_css ) {
-    createGeneratorsForCSS(translator);
+    createGeneratorsForCSS(translator, args_info.line_number_given);
   }
   else {
-    createGenerators(translator);
+    createGenerators(translator, args_info.line_number_given);
   }
   
   if ( is_cgi )
@@ -149,13 +164,13 @@ StartApp::start(int argc, char * argv[])
   
   // first the --input file
   if ( ! args_info.inputs_num )
-    processFile( programName, programVersion, inputFileName, outputFileName, 
+    processFile( args_info.src_lang_arg, inputFileName, outputFileName, 
                  docTitle, docHeader, docFooter, entire_doc, cssUrl ) ;
 
   // let's process other files, if there are any
   if ( args_info.inputs_num && !is_cgi ) {
     for ( i = 0 ; i < (args_info.inputs_num) ; ++i ) {
-      processFile( programName, programVersion, args_info.inputs[i], 
+      processFile( args_info.src_lang_arg, args_info.inputs[i], 
 		   createOutputFileName (args_info.inputs[i],
                                          args_info.output_dir_arg),
 		   docTitle, docHeader, docFooter, entire_doc, cssUrl ) ; 
@@ -185,8 +200,7 @@ StartApp::print_reportbugs()
 }
 
 void
-StartApp::print_version(char *progname, char *progversion)
+StartApp::print_version()
 {
-  cout << "GNU " << progname << " " << progversion << " (GNU " <<
-    PACKAGE << " " << VERSION << ")" << endl;
+  cout << "GNU " << PACKAGE << " " << VERSION << endl;
 }
